# DocumentNode


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 

## Example

```python
from src.client.generated.models.document_node import DocumentNode

# TODO update the JSON string below
json = "{}"
# create an instance of DocumentNode from a JSON string
document_node_instance = DocumentNode.from_json(json)
# print the JSON string representation of the object
print(DocumentNode.to_json())

# convert the object into a dict
document_node_dict = document_node_instance.to_dict()
# create an instance of DocumentNode from a dict
document_node_from_dict = DocumentNode.from_dict(document_node_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


